@@ -7,11 +7,12 @@ from borgmatic.borg import mount as module
 from ..test_verbosity import insert_logging_mock
 
 
-def insert_execute_command_mock(command):
+def insert_execute_command_mock(command, borg_exit_codes=None):
     flexmock(module.environment).should_receive('make_environment')
     flexmock(module).should_receive('execute_command').with_args(
         command,
-        borg_local_path='borg',
+        borg_local_path=command[0],
+        borg_exit_codes=borg_exit_codes,
         extra_environment=None,
     ).once()
 
@@ -93,6 +94,47 @@ def test_mount_archive_calls_borg_with_path_flags():
     )
 
 
+def test_mount_archive_calls_borg_with_local_path():
+    flexmock(module.feature).should_receive('available').and_return(False)
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+    insert_execute_command_mock(('borg1', 'mount', 'repo::archive', '/mnt'))
+
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
+    module.mount_archive(
+        repository_path='repo',
+        archive='archive',
+        mount_arguments=mount_arguments,
+        config={},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+        local_path='borg1',
+    )
+
+
+def test_mount_archive_calls_borg_using_exit_codes():
+    flexmock(module.feature).should_receive('available').and_return(False)
+    flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
+        ('repo::archive',)
+    )
+    borg_exit_codes = flexmock()
+    insert_execute_command_mock(
+        ('borg', 'mount', 'repo::archive', '/mnt'),
+        borg_exit_codes=borg_exit_codes,
+    )
+
+    mount_arguments = flexmock(mount_point='/mnt', options=None, paths=None, foreground=False)
+    module.mount_archive(
+        repository_path='repo',
+        archive='archive',
+        mount_arguments=mount_arguments,
+        config={'borg_exit_codes': borg_exit_codes},
+        local_borg_version='1.2.3',
+        global_arguments=flexmock(log_json=False),
+    )
+
+
 def test_mount_archive_calls_borg_with_remote_path_flags():
     flexmock(module.feature).should_receive('available').and_return(False)
     flexmock(module.flags).should_receive('make_repository_archive_flags').and_return(
@@ -216,6 +258,7 @@ def test_mount_archive_calls_borg_with_foreground_parameter():
         ('borg', 'mount', '--foreground', 'repo::archive', '/mnt'),
         output_file=module.DO_NOT_CAPTURE,
         borg_local_path='borg',
+        borg_exit_codes=None,
         extra_environment=None,
     ).once()
 
@@ -288,6 +331,7 @@ def test_mount_archive_with_date_based_matching_calls_borg_with_date_based_flags
             '/mnt',
         ),
         borg_local_path='borg',
+        borg_exit_codes=None,
         extra_environment=None,
     )
 
